==> activesite-5.x-1.04.tar.gz: activesite/page.tpl.php <==
<?php

/**
 * ------------------------
 * [RU] Шаблон страницы.
 * ------------------------
 */

?><<?php print '?'; ?>xml version="1.0"<?php print '?'; ?>>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language; ?>" lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print rewrite_styles(); ?>
<!--[if lt IE 7]><style type="text/css" media="all"> td.menu-disabled {filter: alpha(opacity='50')} </style><![endif]-->
<!--[if lt IE 8]><style type="text/css" media="all"> td.menu-disabled {filter: alpha(opacity='50')} </style><![endif]-->
<?php print $scripts; ?>
</head>

<?php
	if ($site_name) {$site_name = check_plain($site_name);}
	if ($site_slogan) {$site_slogan = check_plain($site_slogan);}
	$site_title = $site_name ? $site_name : t('Home');
	$if_content_with_cover = strlen($tabs_pri) || strpos($content,'<fieldset');
 ?>

<body class="<?php print $nx_body_classes; ?>">


<table class="page struct">

 <tr>
 <td class="head struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct">
		<a class="logo ff_clear_link nowrap" href="<?php print check_url($base_path); ?>" title="<?php print $site_title; ?>">
		    <img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big LB" alt="" />
		    <img src="<?php print check_url($logo); ?>" class="logo_img" alt="<?php print $site_title; ?>" />
		    <img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big RB" alt="" />
		</a>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
	    <?php print $header; ?>
	</td>
	<td class="column-3 struct">
		<?php
		    global $user;
		    if ($user->uid) {
			$mail = variable_get('site_mail', NULL);
			if ($mail) {print l($mail, 'mailto:'.$mail, array('class' => 'mailto_link')) . ' ('. t('administrator') . ')';}
			print '<img src="'.$full_theme_path.'images/dotted_bounder.png" class="dtd_bnd" alt="" />';
			print l('<img src="'.$full_theme_path.'images/ico-logout.png" alt="" />&nbsp;&nbsp;'.t('logout'), 'logout', array('class' => 'logout_link nowrap'), NULL, NULL, NULL, TRUE);
		    }
		 ?>
		<img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big" alt="" />
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="before_body struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct" style="<?php print $sidebar_left ? '' : 'display:none'; ?>">
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	    <table class="column_header-struct struct">
		<tr><td class="struct">
			<div class="panel_data panel_title">
			    <div class="c_block"><div class="c_block-subStyle">
			        <h2 class="c_block_title"><span><?php global $nx_left_column_title; print $nx_left_column_title; ?></span></h2>
			    </div></div>
			</div>
		    </td>
		    <td class="column_ico-Acc struct">
			<a href="#" class="column_ico column_ico-1 ff_clear_link">
			    <img src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
			</a>
		    </td></tr>
	    </table>
	</td>
	<td class="column-2 struct">
	    <?php
		if (!$breadcrumb) {$breadcrumb = theme('breadcrumb', array('&nbsp;'));}
		print $breadcrumb;
	     ?>
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="body struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct" style="<?php print $sidebar_left ? '' : 'display:none'; ?>">
	    <div class="panel_data">
		<!-- ================================================== -->
		<!-- == left sidebar ================================== -->
		<!-- ================================================== -->
		    <?php if ($sidebar_left): ?>
			<?php print $sidebar_left; ?>
		    <?php endif; ?>
		<!-- ================================================== -->
		<!-- ================================================== -->
	    </div>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
		<!-- ================================================== -->
		<!-- == content ======================================= -->
		<!-- ================================================== -->
		<?php if ($title): print '<h2 class="c_page_title">'. wordwrap($title, 37, "\n", TRUE) .'</h2><div class="c_clear">&nbsp;</div>'; endif; ?>
		<?php print $tabs_sec; ?>
		<?php print $tabs_pri; ?>
		<?php if ($if_content_with_cover) : ?> <table class="content-cover"><tr><td class="content-cover-content"> <?php endif; ?>
		    <?php print $messages; ?>
		    <?php print $help; ?>
		    <?php print $content; ?>
		<?php if ($if_content_with_cover) : ?> </td></tr></table> <?php endif; ?>
		<!-- ================================================== -->
		<!-- ================================================== -->
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="foot struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct">
	    &copy; 2002-2008 <a href="http://www.activemoda.ru" class="nowrap">ActiveModa</a> | <a href="http://www.activemoda.ru/tech/activesite/" class="nowrap">О программе</a>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
	    <?php print $footer_region; ?>
	    <?php if (strlen($footer_message) > 1) : ?>
		<div class="footer_message">
		    <?php print $footer_message; ?>
		</div>
	    <?php endif; ?>
	</td>
	<td class="column-3 struct">
	    <a href="mailto:welcome@activemoda.ru">Поддержка</a> | <span class="nowrap">Версия 3.0</span>
	</td></tr>
    </table>
 </td>
 </tr>

</table>


<div class="techno_bottom_region">
    <center><?php print $techno_bottom_region; ?></center>
</div>


<?php global $user; if ($user->uid == 0) : ?>
<div class="preLoad">
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-collapsed-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-expanded-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/panel-BG.png)">&nbsp;</div>
</div>
<?php endif; ?>

<?php print $closure; ?>
</body>
</html>

==> activesite-5.x-1.07.tar.gz: activesite/page.tpl.php <==
<?php

/**
 * ------------------------
 * [RU] Шаблон страницы.
 * ------------------------
 */

?><<?php print '?'; ?>xml version="1.0"<?php print '?'; ?>>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language; ?>" lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print rewrite_styles(); ?>
<!--[if lt IE 7]><style type="text/css" media="all"> td.menu-disabled {filter: alpha(opacity='50')} </style><![endif]-->
<!--[if lt IE 8]><style type="text/css" media="all"> td.menu-disabled {filter: alpha(opacity='50')} </style><![endif]-->
<?php print $scripts; ?>
</head>

<?php
	if ($site_name) {$site_name = check_plain($site_name);}
	if ($site_slogan) {$site_slogan = check_plain($site_slogan);}
	$site_title = $site_name ? $site_name : t('Home');
	$if_content_with_cover = strlen($tabs_pri) || strpos($content,'<fieldset');
 ?>

<body class="<?php print $nx_body_classes; ?>">


<table class="page struct">

 <tr>
 <td class="head struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct">
		<a class="logo ff_clear_link nowrap" href="<?php print check_url($base_path); ?>" title="<?php print $site_title; ?>">
		    <img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big LB" alt="" />
		    <img src="<?php print check_url($logo); ?>" class="logo_img" alt="<?php print $site_title; ?>" />
		    <img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big RB" alt="" />
		</a>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
	    <?php print $header; ?>
	</td>
	<td class="column-3 struct">
		<?php
		    global $user;
		    if ($user->uid) {
			$mail = variable_get('site_mail', NULL);
			if ($mail) {print l($mail, 'mailto:'.$mail, array('class' => 'mailto_link')) . ' ('. t('administrator') . ')';}
			print '<img src="'.$full_theme_path.'images/dotted_bounder.png" class="dtd_bnd" alt="" />';
			print l('<img src="'.$full_theme_path.'images/ico-logout.png" alt="" />&nbsp;&nbsp;'.t('logout'), 'logout', array('class' => 'logout_link nowrap'), NULL, NULL, NULL, TRUE);
		    }
		 ?>
		<img src="<?php print $full_theme_path; ?>images/dotted_bounder-big.png" class="dtd_bnd-big" alt="" />
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="before_body struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct" style="<?php print $sidebar_left ? '' : 'display:none'; ?>">
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	    <table class="column_header-struct struct">
		<tr><td class="struct">
			<div class="panel_data panel_title">
			    <div class="c_block"><div class="c_block-subStyle">
			        <h2 class="c_block_title"><span><?php global $nx_left_column_title; print $nx_left_column_title; ?></span></h2>
			    </div></div>
			</div>
		    </td>
		    <td class="column_ico-Acc struct">
			<a href="#" class="column_ico column_ico-1 ff_clear_link">
			    <img src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
			</a>
		    </td></tr>
	    </table>
	</td>
	<td class="column-2 struct">
	    <?php
		if (!$breadcrumb) {$breadcrumb = theme('breadcrumb', array('&nbsp;'));}
		print $breadcrumb;
	     ?>
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="body struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct" style="<?php print $sidebar_left ? '' : 'display:none'; ?>">
	    <div class="panel_data">
		<!-- ================================================== -->
		<!-- == left sidebar ================================== -->
		<!-- ================================================== -->
		    <?php if ($sidebar_left): ?>
			<?php print $sidebar_left; ?>
		    <?php endif; ?>
		<!-- ================================================== -->
		<!-- ================================================== -->
	    </div>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
		<!-- ================================================== -->
		<!-- == content ======================================= -->
		<!-- ================================================== -->
		<?php if ($title): print '<h2 class="c_page_title">'. $title .'</h2><div class="c_clear">&nbsp;</div>'; endif; ?>
		<?php print $tabs_sec; ?>
		<?php print $tabs_pri; ?>
		<?php if ($if_content_with_cover) : ?> <table class="content-cover"><tr><td class="content-cover-content"> <?php endif; ?>
		    <?php print $messages; ?>
		    <?php print $help; ?>
		    <?php print $content; ?>
		<?php if ($if_content_with_cover) : ?> </td></tr></table> <?php endif; ?>
		<!-- ================================================== -->
		<!-- ================================================== -->
	</td></tr>
    </table>
 </td>
 </tr>

 <!-- ======================================================= -->

 <tr>
 <td class="foot struct">
    <table class="columns struct"><tr>
	<td class="column-1 struct">
	    &copy; 2002-2008 <a href="http://www.activemoda.ru" class="nowrap">ActiveModa</a> | <a href="http://www.activemoda.ru/tech/activesite/" class="nowrap">О программе</a>
	    <img class="column_1-min_size" src="<?php print $full_theme_path; ?>images/empty.gif" alt="" />
	</td>
	<td class="column-2 struct">
	    <?php print $footer_region; ?>
	    <?php if (strlen($footer_message) > 1) : ?>
		<div class="footer_message">
		    <?php print $footer_message; ?>
		</div>
	    <?php endif; ?>
	</td>
	<td class="column-3 struct">
	    <a href="mailto:welcome@activemoda.ru">Поддержка</a> | <span class="nowrap">Версия 3.0</span>
	</td></tr>
    </table>
 </td>
 </tr>

</table>


<div class="techno_bottom_region">
    <center><?php print $techno_bottom_region; ?></center>
</div>


<?php global $user; if ($user->uid == 0) : ?>
<div class="preLoad">
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-collapsed-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/fieldset-Title-expanded-BG.png)">&nbsp;</div>
    <div style="background:url(<?php print $full_theme_path; ?>images/panel-BG.png)">&nbsp;</div>
</div>
<?php endif; ?>

<?php print $closure; ?>
</body>
</html>
